@@ -1,4 +1,4 @@
-# $Id: First.pm 577 2005-07-09 02:23:55Z claco $
+# $Id: First.pm 706 2005-08-10 01:41:59Z claco $
 package Handel::TestPlugins::First;
 use strict;
 use warnings;
@@ -35,7 +35,7 @@ sub handler {
 
     $self->{'handler_called'}++;
 
-    return CHECKOUT_STATUS_OK;
+    return CHECKOUT_HANDLER_OK;
 };
 
 1;
\ No newline at end of file
